#
Summary:	Toolkit for developing GIS (Geographic Information Systems) applications
Name:		mapnik
Version:	2.2.0
Release:	1
License:	LGPL v2.1
Group:		Applications
Source0:	https://github.com/mapnik/mapnik/archive/v%{version}.tar.gz
# Source0-md5:	b837931c7f1a4dc630d8550d3e635036
Patch0:		%{name}-boost_lib_names.patch
Patch1:		mapnik-boost-megadiff.diff
Patch2:		%{name}-build.patch
URL:		http://mapnik.org/
BuildRequires:	boost-devel
BuildRequires:	boost-python-devel
BuildRequires:	cairomm-devel
BuildRequires:	curl-devel
BuildRequires:	freetype-devel
BuildRequires:	gdal-devel
BuildRequires:	libicu-devel
BuildRequires:	libjpeg-devel
BuildRequires:	libltdl-devel
BuildRequires:	libpng-devel
BuildRequires:	librasterlite-devel
BuildRequires:	libtiff-devel
BuildRequires:	libxml2-devel
BuildRequires:	pkgconfig
BuildRequires:	postgresql-devel
BuildRequires:	proj-devel
BuildRequires:	python-devel
BuildRequires:	python-pycairo-devel
BuildRequires:	rpm-pythonprov
BuildRequires:	scons
BuildRequires:	sqlite3-devel
BuildRequires:	zlib-devel
Suggests:	fonts-TTF-DejaVu
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Mapnik is a Free Toolkit for developing mapping applications. It's
written in C++ and there are Python bindings to facilitate fast-paced
agile development. It can comfortably be used for both desktop and web
development, which was something I wanted from the beginning.

Mapnik is about making beautiful maps. It uses the AGG library and
offers world class anti-aliasing rendering with subpixel accuracy for
geographic data. It is written from scratch in modern C++ and doesn't
suffer from design decisions made a decade ago.

%package -n python-%{name}
Summary:	Python bindings for Mapnik
Group:		Libraries/Python
Requires:	%{name} = %{version}-%{release}

%description -n python-%{name}
Python binding for Mapnik, the toolkit for developing GIS (Geographic
Information Systems) applications.

%package devel
Summary:	Header files for Mapnik
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki Mapnik
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}

%description devel
Header files for Mapnik.

%description devel -l pl.UTF-8
Pliki nagłówkowe biblioteki Mapnik.

%package static
Summary:	Static Mapnik library
Summary(pl.UTF-8):	Statyczna biblioteka Mapnik
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static Mapnik library.

%description static -l pl.UTF-8
Statyczna biblioteka Mapnik.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build
%scons \
	PREFIX=%{_prefix} \
	BOOST_TOOLKIT=gcc43 \
	INPUT_PLUGINS='raster,rasterlite,sqlite,osm,gdal,shape,postgis,ogr,occi,csv,geojson' \
	SYSTEM_FONTS=%{_datadir}/fonts/TTF \
	LIBDIR_SCHEMA=%{_lib} \
	SVG2PNG=True

%install
rm -rf $RPM_BUILD_ROOT

%scons install \
	DESTDIR=$RPM_BUILD_ROOT \
	PREFIX=%{_prefix} \
	BOOST_TOOLKIT=gcc43 \
	INPUT_PLUGINS='raster,rasterlite,sqlite,osm,gdal,shape,postgis,ogr,occi,csv,geojson' \
	SYSTEM_FONTS=%{_datadir}/fonts/TTF \
	LIBDIR_SCHEMA=%{_lib} \
	SVG2PNG=True

%py_ocomp $RPM_BUILD_ROOT%{py_sitedir}
%py_comp $RPM_BUILD_ROOT%{py_sitedir}
%py_postclean

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc AUTHORS.md CHANGELOG.md INSTALL.md README.md
%attr(755,root,root) %{_bindir}/mapnik-config
%attr(755,root,root) %{_bindir}/mapnik-speed-check
%attr(755,root,root) %{_bindir}/shapeindex
%attr(755,root,root) %{_bindir}/upgrade_map_xml.py
%attr(755,root,root) %{_libdir}/libmapnik.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libmapnik.so.2.2
%dir %{_libdir}/mapnik
%dir %{_libdir}/mapnik/input
%attr(755,root,root) %{_libdir}/mapnik/input/csv.input
%attr(755,root,root) %{_libdir}/mapnik/input/gdal.input
%attr(755,root,root) %{_libdir}/mapnik/input/geojson.input
%attr(755,root,root) %{_libdir}/mapnik/input/ogr.input
%attr(755,root,root) %{_libdir}/mapnik/input/osm.input
%attr(755,root,root) %{_libdir}/mapnik/input/postgis.input
%attr(755,root,root) %{_libdir}/mapnik/input/raster.input
%attr(755,root,root) %{_libdir}/mapnik/input/rasterlite.input
%attr(755,root,root) %{_libdir}/mapnik/input/shape.input
%attr(755,root,root) %{_libdir}/mapnik/input/sqlite.input

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libmapnik.so
%{_includedir}/mapnik

%files -n python-%{name}
%defattr(644,root,root,755)
%dir %{py_sitedir}/mapnik
%{py_sitedir}/mapnik/*.py[co]
%attr(755,root,root) %{py_sitedir}/mapnik/_mapnik.so
%dir %{py_sitedir}/mapnik2
%{py_sitedir}/mapnik2/*.py[co]
%changelog
* Mon Nov 10 2014 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/mapnik.git;a=log;h=master

* Mon Nov 10 2014 Arkadiusz Miśkiewicz <arekm@maven.pl> eaba878
- up to 2.2.0

* Mon Oct 27 2014 Jan Rękorajski <baggins@pld-linux.org> 5a68133
- release 18 (by relup.sh)

* Sat Oct 25 2014 Jan Rękorajski <baggins@pld-linux.org> 379715b
- rebuild with boost 1.56.0
- release 17 (by relup.sh)

* Wed Oct 08 2014 Arkadiusz Miśkiewicz <arekm@maven.pl> 61d631a
- release 16 (by relup.sh)

* Sun Feb 02 2014 Jan Rękorajski <baggins@pld-linux.org> 8695aaf
- - rebuild with boost 1.55.0
- release 15 (by relup.sh)

* Fri Nov 01 2013 Arkadiusz Miśkiewicz <arekm@maven.pl> 4c770f3
- release 14 (by relup.sh)

* Tue Oct 29 2013 Arkadiusz Miśkiewicz <arekm@maven.pl> 405157f
- release 13 (by relup.sh)

* Tue Jul 09 2013 Jan Rękorajski <baggins@pld-linux.org> e7bd06b
- release 12 (by relup.sh)

* Sun Jul 07 2013 Jan Rękorajski <baggins@pld-linux.org> bbd3537
- release 11 (by relup.sh)

* Wed Sep 19 2012 Arkadiusz Miśkiewicz <arekm@maven.pl> a70f649
- release 10 (by relup.sh)

* Wed Jul 11 2012 Jan Rękorajski <baggins@pld-linux.org> 85138c3
- Rebuild with boost 1.50
Release 9

* Sun Mar 11 2012 Arkadiusz Miśkiewicz <arekm@maven.pl> f9fbea9
- release 8

* Mon Feb 13 2012 Adam Gołębiowski <adamg@pld-linux.org> 19399a7
- release 7 (rebuild against libpng-1.5)

* Sun Feb 12 2012 Arkadiusz Miśkiewicz <arekm@maven.pl> bdfc07e
- release 6

* Tue Feb 07 2012 Arkadiusz Miśkiewicz <arekm@maven.pl> 049b5ce
- release 5

* Fri Jan 13 2012 Arkadiusz Miśkiewicz <arekm@maven.pl> 9e44510
- release 4

* Tue Dec 20 2011 Arkadiusz Miśkiewicz <arekm@maven.pl> df3038b
- release 3

* Fri Oct 14 2011 Arkadiusz Miśkiewicz <arekm@maven.pl> b7cacf2
- release 2

* Thu Oct 13 2011 Artur Frysiak <artur@frysiak.net> 79c2f23
- up to 2.0.0
- enable all input plugins
- more verbose %files

* Sun Oct 09 2011 Arkadiusz Miśkiewicz <arekm@maven.pl> 76e4891
- release 4

